#!/usr/bin/env python3

from argparse import Namespace
from pathlib import Path
from typing import Any

import yaml

from .tree import SourceIndex, SourceNode


class Context:
    def __init__(self) -> None:
        self.source_dir: Path | None = None
        self.config: dict[str, Any] = {}
        self.src_index: SourceIndex | None = None
        self.current_node: SourceNode | None = None

    def load_config(self, args: Namespace) -> None:
        config_filename: str = str(args.config) if args.config else ".dragonglass"
        assert self.source_dir is not None
        config_path = self.source_dir / config_filename
        if config_path.exists() and config_path.is_file():
            with open(config_path, "r") as f:
                self.config = yaml.full_load(f)

    @property
    def url_prefix(self) -> str:
        rc = self.config.get("url_prefix", "/")
        return rc if rc.endswith("/") else rc + '/'


